==> jboss-eap-7.4.2-core-src.zip: jboss-eap-7.4-core-src/cli/src/main/java/org/jboss/as/cli/RequestWithAttachments.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2016, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.as.cli;

import java.util.List;
import java.util.Objects;
import org.jboss.dmr.ModelNode;

/**
 *
 * @author jdenise@redhat.com
 */
public final class RequestWithAttachments {

    private final Attachments attachments;
    private final ModelNode request;

    public RequestWithAttachments(ModelNode request, Attachments attachments) {
        Objects.requireNonNull(request);
        Objects.requireNonNull(attachments);

        this.request = request;
        this.attachments = attachments;
    }

    public ModelNode getRequest() {
        return request;
    }

    public List<String> getAttachedFiles() {
        return attachments.getAttachedFiles();
    }
}

==> jboss-eap-8.0.10-core-src.zip: jboss-eap-8.0-core-src/cli/src/main/java/org/jboss/as/cli/RequestWithAttachments.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2016, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.as.cli;

import static org.wildfly.common.Assert.checkNotNullParamWithNullPointerException;

import java.util.List;

import org.jboss.dmr.ModelNode;

/**
 *
 * @author jdenise@redhat.com
 */
public final class RequestWithAttachments {

    private final Attachments attachments;
    private final ModelNode request;

    public RequestWithAttachments(ModelNode request, Attachments attachments) {
        this.request = checkNotNullParamWithNullPointerException("request", request);
        this.attachments = checkNotNullParamWithNullPointerException("attachments", attachments);
    }

    public ModelNode getRequest() {
        return request;
    }

    public List<String> getAttachedFiles() {
        return attachments.getAttachedFiles();
    }
}
